OC.L10N.register(
    "core",
    {
    "Please select a file." : "Ver venleg og vel ei fil.",
    "File is too big" : "Fila er for stor",
    "Invalid file provided" : "Ugyldig fil",
    "No image or file provided" : "Inga bilete eller fil gjeve",
    "Unknown filetype" : "Ukjend filtype",
    "Invalid image" : "Ugyldig bilete",
    "An error occurred. Please contact your admin." : "Det oppstod ein feil. Ver venleg og kontakt systemadministrator.",
    "No temporary profile picture available, try again" : "Inga midlertidig profilbilete tilgjengeleg, prøv igjen",
    "No crop data provided" : "Ingen beskjeringsdata gjeve",
    "No valid crop data provided" : "Ingen beskjeringsdata gjeve",
    "Crop is not square" : "Beskjeringa er ikkje kvadratisk",
    "Couldn't reset password because the token is invalid" : "Kunne ikkje nullstilla passordet sidan tokenet er ugyldig",
    "Couldn't reset password because the token is expired" : "Kunne ikkje nullstilla passordet sidan tokenet er utløpt",
    "%s password reset" : "%s passordnullstilling",
    "Couldn't send reset email. Please contact your administrator." : "Kunne ikkje senda e-post for nullstilling, kontakt administratoren.",
    "Couldn't send mail to following users: %s " : "Kunne ikkje sende e-post til følgande brukarar: %s ",
    "Preparing update" : "Klargjer forbetring",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Åtvaring ved reparering:",
    "Repair error: " : "Feil ved reparering:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ver venleg og bruk kommando linje forbedring fordi automatisk forbedring ikkje er aktivert i config.php",
    "[%d / %d]: Checking table %s" : "[%d / %d]: undersøkjer tabell %s",
    "Turned on maintenance mode" : "Skrudde på vedlikehaldsmodus",
    "Turned off maintenance mode" : "Skrudde av vedlikehaldsmodus",
    "Maintenance mode is kept active" : "Forbedringsmodus er halde aktiv",
    "Updating database schema" : "Oppdaterer database skjema",
    "Updated database" : "Database oppdatert",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Kontroll av om database skjema kan forbedrast (kan ta lang tid ved stor database)",
    "Checked database schema update" : "Kontrollert forbedring av database skjema",
    "Checking updates of apps" : "Kontroller av forbedring av program",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontroll av om database skjema til %s kan forbedrast (kan ta lang tid ved stor database)",
    "Checked database schema update for apps" : "Kontrollert forbedring av database skjema for program",
    "Updated \"%s\" to %s" : "Oppdaterte «%s» til %s",
    "Set log level to debug" : "Set logg nivå til feilsøking",
    "Reset log level" : "Nulstill logg nivå",
    "Starting code integrity check" : "Startar kontroll av integritet for kode",
    "Finished code integrity check" : "Fullførte kontroll av integirtet for kode",
    "%s (3rdparty)" : "%s (tredjeparts)",
    "%s (incompatible)" : "%s (inkompatibel)",
    "Following apps have been disabled: %s" : "Desse programma er inaktivert: %s",
    "Already up to date" : "Allereie oppdatert",
    "Sunday" : "Søndag",
    "Monday" : "Måndag",
    "Tuesday" : "Tysdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Laurdag",
    "Sun." : "Søn.",
    "Mon." : "Mån.",
    "Tue." : "Tys.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lau.",
    "Su" : "Su",
    "Mo" : "Må",
    "Tu" : "Ty",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "La",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar,",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Problem med kontroll av integritet for kode. Meir informasjon....</a>",
    "Settings" : "Innstillingar",
    "Problem loading page, reloading in 5 seconds" : "Problem med lasting av side, prøver på ny om 5 sekund",
    "Saving..." : "Lagrar …",
    "Dismiss" : "Forkast",
    "seconds ago" : "sekund sidan",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Lenkja til å nullstilla passordet med er sendt til e-posten din.<br>Sjå i spam-/søppelmappa di viss du ikkje ser e-posten innan rimeleg tid.<br>Spør din lokale administrator viss han ikkje er der heller.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Filene dine er krypterte. Viss du ikkje har skrudd på gjenopprettingsnøkkelen, finst det ingen måte å få tilbake dataa dine når passordet ditt er nullstilt. <br />Viss du ikkje er sikker på kva du skal gjera bør du spørja administratoren din før du går vidare. <br />Vil du verkeleg fortsetja?",
    "I know what I'm doing" : "Eg veit kva eg gjer",
    "Password can not be changed. Please contact your administrator." : "Passord kan ikkje endrast, kontakt administratoren.",
    "No" : "Nei",
    "Yes" : "Ja",
    "Choose" : "Vel",
    "Error loading file picker template: {error}" : "Klarte ikkje å lasta filplukkarmal: {error}",
    "Ok" : "Greitt",
    "Error loading message template: {error}" : "Klarte ikkje å lasta meldingsmal: {error}",
    "read-only" : "skriveverna",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonfliktar"],
    "One file conflict" : "Éin filkonflikt",
    "New Files" : "Nye filer",
    "Already existing files" : "Eksisterande filer",
    "Which files do you want to keep?" : "Kva filer vil du spara?",
    "If you select both versions, the copied file will have a number added to its name." : "Viss du vel begge utgåvene, vil den kopierte fila få eit tal lagt til namnet.",
    "Cancel" : "Avbryt",
    "Continue" : "Gå vidare",
    "(all selected)" : "(alle valte)",
    "({count} selected)" : "({count} valte)",
    "Error loading file exists template" : "Klarte ikkje å lasta fil-finst-mal",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Middelmåtig passord",
    "Good password" : "Godt passord",
    "Strong password" : "Sterkt passord",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Tenaren din er ikkje enno rett innstilt til å tilby filsynkronisering sidan WebDAV-grensesnittet ser ut til å vera øydelagt.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Tenaren din er ikkje enno rett innstilt til å løyse  \"{url}\". Meir informasjon finst i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjon</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Denne tenaren har ikkje ei fungerande nettilkopling. Dette vil seia at visse funksjonar, som montering av ekstern lagring, meldingar om oppdateringar eller installering av tredjepartsprogram, ikkje vil fungera. Det kan òg henda at du ikkje får tilgang til filene dine utanfrå, eller ikkje får sendt varslingsepostar. Me rår deg til å skru på nettilkoplinga for denne tenaren viss du ønskjer desse funksjonane.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Ingen minnehurtiglager er definert. For betre respons ver venleg å definere hurtiglager hvis tilgjengeleg. Meir informasjon finst i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjon</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Tenaren din er ikkje enno rett innstilt til å løyse  \"{url}\". Meir informasjon finst i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjon</a>.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Du brukar PHP {version}. Vi oppfordrar til å forbetre din PHP versjon med forbetringar i <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">yting og sikkerheit som er utført av PHP gruppa</a> så snart din distribusjon støttar denne.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Konfigurasjon for overskrift/hode for reversert mellomtenar er feil, eller du brukar ownCloud fra en klarert mellomtener. Hvis du ikkje brukar ownCloud fra en klarert mellomtener, er dette eit sikkerhetsproblem og kan tillate ein angripar å forfalske sin IP-adresse som er synlig for ownCloud. Ytterligere informasjon finn du i vår <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjon</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Minnehurtiglager er definert som distribuert hurtiglager men feil PHP modul \"memcache\" er installert. \\OC\\Memcache\\Memcached støttar kun \"memcached\" go ikkje \"memcache\". Sjå <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki om modulane</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Enkelte filer er ikkje godkjend i kontroll av integritet. Informasjon om korleis ein løyser dette fins i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjon</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Filer som ikkje er godkjend…</a> / <a href=\"{rescanEndpoint}\">Søk på ny…</a>)",
    "Error occurred while checking server setup" : "Feil ved kontroll av oppset for tenaren",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Datamappa og filene dine er sannsynlegvis leselege frå nettet. Fila .htaccess fungerer ikkje. Me rår deg sterkt til å konfigurera vevtenaren din sånn at datamappa di ikkje lenger er tilgjengeleg. Alternativt kan du flytta datamappa ut av dokumentrota til vevtenaren.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP header er ikkje konfigurert lik \"{expected}\". Dette er ein potensiell risiko for sikkerheit og personvern. Vi vil anbefale å endre desse innstillingane.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "\"Strict-Transport-Security\" HTTP header er ikkje konfigurert til minimum \"{seconds}\" sekund. For betre sikkerheit vil vi anbefala å bruke HSTS som bekreve i våre <a href=\"{docUrl}\" rel=\"noreferrer\">sikkerheitstips</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du når denne tjenaren med HTTP. Vi vil sterkt anbefala å konfigurera tenaren til å bruke kun HTTPS som beskreve i våre <a href=\"{docUrl}\">sikkerheitstips</a>.",
    "Shared" : "Delt",
    "Shared with {recipients}" : "Delt med {recipients}",
    "Error" : "Feil",
    "Error while sharing" : "Feil ved deling",
    "Error while unsharing" : "Feil ved udeling",
    "The public link will expire no later than {days} days after it is created" : "Den offentlege lenka har gyldigheit i  {days} dagar etter den er oppretta",
    "Set expiration date" : "Set utløpsdato",
    "Expiration" : "Utløp",
    "Expiration date" : "Utløpsdato",
    "Link" : "Lenkje",
    "Edit" : "Endra",
    "Remove" : "Fjern",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikkje støtta!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "Choose a password for the public link" : "Vel eit passord for den offentlege lenkja",
    "Password" : "Passord",
    "Name" : "Namn",
    "Allow editing" : "Tillat endring",
    "Save" : "Lagra",
    "Share to Twitter. Opens in a new window." : "Del med Twitter, opnar i nytt vindauge.",
    "Share to Facebook. Opens in a new window." : "Del med Facebook, opnar i nytt vindauge.",
    "Share to Diaspora. Opens in a new window." : "Del med Diaspora, opnar i nytt vindauge.",
    "Share to Google+. Opens in a new window." : "Del med Google+, opnar i nytt vindauge.",
    "Share via email. Opens your mail client." : "Del med e-post, opnar i din e-post klient.",
    "Error while sending notification" : "Feil ved sending av varsel",
    "Sending ..." : "Sender …",
    "Email sent" : "E-post sendt",
    "Email link to person" : "Send lenkja over e-post",
    "Send link via email" : "Send lenkja via e-post",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppa {group} av {owner}",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "group" : "gruppe",
    "remote" : "ekstern",
    "notify by email" : "varsel via e-post",
    "Unshare" : "Udel",
    "can share" : "kan dela",
    "can edit" : "kan endra",
    "create" : "lag",
    "change" : "endra",
    "delete" : "slett",
    "access control" : "tilgangskontroll",
    "Could not unshare" : "Kan ikkje slå av deling",
    "Share details could not be loaded for this item." : "Detaljar om deling kan ikke lesast for dette element.",
    "No users or groups found for {search}" : "Ingen brukar eller gruppe funnen for {search}",
    "No users found for {search}" : "Ingen brukar funnen for {search}",
    "An error occurred. Please try again" : "Ein feil oppstod. Ver venleg prøv på ny",
    "{sharee} (group)" : "{sharee} (group)",
    "{sharee} (at {server})" : "{sharee} (at {server})",
    "{sharee} (remote)" : "{sharee} (remote)",
    "Share" : "Del",
    "Resharing is not allowed" : "Vidaredeling er ikkje tillate",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Del med folk på annan ownCloud med syntaks username@example.com/owncloud",
    "Share with users…" : "Del med brukarar...",
    "Share with users, groups or remote users…" : "Del med brukar, gruppe enn ekstern brukar...",
    "Share with users or groups…" : "Del med brukar enn gruppe...",
    "Share with users or remote users…" : "Del med brukar enn ekstern brukar...",
    "Error removing share" : "Feil ved fjerning av deling",
    "Warning" : "Åtvaring",
    "Non-existing tag #{tag}" : "Merke finst ikkje #{tag}",
    "restricted" : "avgrensa",
    "invisible" : "usynleg",
    "({scope})" : "({scope})",
    "Delete" : "Slett",
    "Rename" : "Endra namn",
    "Collaborative tags" : "Samarbeids merker",
    "The object type is not specified." : "Objekttypen er ikkje spesifisert.",
    "Enter new" : "Oppgje ny",
    "Add" : "Legg til",
    "Edit tags" : "Endra merker",
    "Error loading dialog template: {error}" : "Klarte ikkje å lasta meldingsmal: {error}",
    "No tags selected for deletion." : "Ingen merke valt for sletting.",
    "unknown text" : "ukjend tekst",
    "Hello world!" : "Hei på deg univers!",
    "sunny" : "solskin",
    "Hello {name}, the weather is {weather}" : "Hei {name}, været er {weather}",
    "Hello {name}" : "Hei {name}",
    "new" : "ny",
    "_download %n file_::_download %n files_" : ["last ned %n fil","last ned %n filer"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Forbetring er starta, stenging av denne sida kan avbryte prosess i enkelte miljø.",
    "Updating to {version}" : "Oppdaterer til {version}",
    "An error occurred." : "Ein feil oppstod!",
    "Please reload the page." : "Ver venleg og last sida på nytt.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Forbetring var ikkje vellukka. For meir informasjon <a href=\"{url}\">sjå vårt forum</a> for beskriving av dette tilfellet.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Oppdateringa feila. Ver venleg og rapporter feilen til <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud-fellesskapet</a>.",
    "The update was successful. There were warnings." : "Forbetring var vellukka. Det var åtvaring.",
    "The update was successful. Redirecting you to ownCloud now." : "Oppdateringa er fullført. Sender deg vidare til ownCloud no.",
    "Searching other places" : "Søkjer andre plassar",
    "No search results in other folders" : "Ingen resultat i andre mapper",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} søke resultat i anna katalog","{count} search results in other folders"],
    "Personal" : "Personleg",
    "Users" : "Brukarar",
    "Apps" : "Program",
    "Admin" : "Admin",
    "Help" : "Hjelp",
    "Access forbidden" : "Tilgang forbudt",
    "File not found" : "Fann ikkje fila",
    "The specified document has not been found on the server." : "Dokumentet er ikkje funnen på tenaren.",
    "You can click here to return to %s." : "Du kan klikke her for å gå til %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hei du!\n\n%s har delt %s med deg.\nSjå det på %s\n\n",
    "The share will expire on %s." : "Deling har gyldigheit til %s.",
    "Cheers!" : "Skål!",
    "Internal Server Error" : "Intern feil i tenaren",
    "The server encountered an internal error and was unable to complete your request." : "Tenaren fekk ein intern feil og kan ikkje fullføre din førespurnad.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Ver venleg å kontakt administrator vhis denne feilen oppstår fleire gonger, ver venleg å ta med tekniske detaljar nedanfor i din henvendelse.",
    "More details can be found in the server log." : "Meir delajar i logg til tenaren.",
    "Technical details" : "Tekniske detaljer",
    "Remote Address: %s" : "Ekstern adresse %s",
    "Request ID: %s" : "Førespurnad ID %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Melding: %s",
    "File: %s" : "Fil: %s",
    "Line: %s" : "Linje: %s",
    "Trace" : "Spor",
    "Create an <strong>admin account</strong>" : "Lag ein <strong>admin-konto</strong>",
    "Username" : "Brukarnamn",
    "Storage & database" : "Lager og database",
    "Data folder" : "Datamappe",
    "Configure the database" : "Set opp databasen",
    "Only %s is available." : "Kun %s er tilgjengeleg",
    "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver ytterlegare PHP modular for å velje annan type database",
    "For more details check out the documentation." : "For meir detaljar sjå dokumentasjon.",
    "Database user" : "Databasebrukar",
    "Database password" : "Databasepassord",
    "Database name" : "Databasenamn",
    "Database tablespace" : "Tabellnamnrom for database",
    "Database host" : "Databasetenar",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Ver venleg å oppgje port nummer med maskin namn (til dømes, localhost: 5432).",
    "Performance warning" : "Åtvaring om kapasitet",
    "SQLite will be used as database." : "SQLite vil bli brukt som database",
    "For larger installations we recommend to choose a different database backend." : "For større installasjonar vil vi anbefale å velje ein annan database motor.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Spesielt ved bruk av klient for å synkronisera bør ein ikkje bruka SQLite.",
    "Finish setup" : "Fullfør oppsettet",
    "Finishing …" : "Avslutning...",
    "Need help?" : "Treng du hjelp?",
    "See the documentation" : "Sjå dokumentasjon",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei der,<br><br>nemner berre at %s delte <strong>%s</strong> med deg.<br><a href=\"%s\">Talast!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne sida krever JavaScript for å fungera. Ver venleg {linkstart}enable JavaScript{linkend} og last inn sida på ny.",
    "Log out" : "Logg ut",
    "Search" : "Søk",
    "Server side authentication failed!" : "Feil ved autentisering på tenaren!",
    "Please contact your administrator." : "Ver venleg kontakt din administrator.",
    "An internal error occurred." : "Ein intern feil oppstod!",
    "Please try again or contact your administrator." : "Ver venleg prøv på ny enn kontakt din administrator.",
    "Username or email" : "Brukarnamn eller epost!",
    "Log in" : "Logg inn",
    "Wrong password. Reset it?" : "Feil passord, nullstilt passord?",
    "Wrong password." : "Feil passord.",
    "Stay logged in" : "Varig innlogging",
    "Alternative Logins" : "Alternative innloggingar",
    "Use the following link to reset your password: {link}" : "Klikk følgjande lenkje til å nullstilla passordet ditt: {link}",
    "New password" : "Nytt passord",
    "New Password" : "Nytt passord",
    "Reset password" : "Nullstill passord",
    "This ownCloud instance is currently in single user mode." : "Denne ownCloud førekomsten er i ein-brukar modus.",
    "This means only administrators can use the instance." : "Dette betyr at kun adminitrator kan bruke denne førekomsten.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt din system administrator hvis denne meldinga held fram enn oppstod uventa.",
    "Thank you for your patience." : "Takk for ditt tolmod.",
    "Two-step verification" : "To-steg verifikasjon",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Forbetra sikkerheit er tilgjengeleg for din konto. Ver venleg å autentiser ved å bruke to-faktor pålogging.",
    "Cancel login" : "Avbryta pålogging",
    "Please authenticate using the selected factor." : "Ver venleg å autentiser med vald faktor.",
    "An error occurred while verifying the token" : "Feil ved verifikasjon av symbol.",
    "You are accessing the server from an untrusted domain." : "Du når denne tenaren frå eit domene som ikkje er klarert.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Kontakt din administrator. Hvis du er administrator for denne tenaren, konfigurer \"trusted_domains\" setting i config/config.php. Eksempel finst i config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "AVhengig av oppsett kan du som administrator bruke knappen nedanfor for å stole på dette domenet.",
    "Add \"%s\" as trusted domain" : "Legg til \"%s\" som godkjent domene",
    "App update required" : "Forbetring av program er påkrevd",
    "%s will be updated to version %s" : "%s vil bli forbetra til versjon %s",
    "These apps will be updated:" : "Desse programma vil bli oppdatert:",
    "The theme %s has been disabled." : "Tema %s er deaktivert.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ver venleg å forsikra deg om at database, mappe med konfigurasjon og mappe med data er sikkerheitskopiert før du fortsett.",
    "Start update" : "Start forbetring",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For å unngå tidsavbrot på store førekomstar, bruk fyljande kommando frå mappe med installasjon:",
    "Detailed logs" : "Detaljert logg",
    "Update needed" : "Forbetring trengs",
    "Please use the command line updater because you have a big instance." : "Ver venleg og bruk kommando linje forbedring fordi du har ein stor førekomst",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "For hjelp, sjå <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentasjon</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s førekomst er i forbetrings modus som kan ta ei stund.",
    "This page will refresh itself when the %s instance is available again." : "Denne sida vil lastast på ny når %s førekomsten er tilgjengeleg att.",
    "Could not reset password because the token is invalid" : "Kunne ikkje nullstille passord fordi pollett er  ugyldig",
    "Could not reset password because the token expired" : "Kunne ikkje nullstille passord fordi pollet er utgått",
    "Could not reset password because the token does not match" : "Kunne ikkje nullstille passord fordi pollett stemmer ikkje",
    "Expiration date is required" : "Utløp dato er krevd",
    "Remove link" : "Fjern lenke",
    "Create public link" : "Opprett offentleg lenke",
    "Copy to clipboard" : "Kopier til utklippstavle",
    "There are currently no link shares, you can create one" : "Det er ikkje nokon delt lenke, du kan opprette ei",
    "Anyone with the link has access to the file/folder" : "Alle med lenke har tilgang til fil eller mappe",
    "Password required" : "Passord påkrevd",
    "Filename" : "Filnavn",
    "Remove password" : "Fjern passord",
    "User and Groups" : "Brukar og grupper",
    "Public Links" : "Offentlege lenker",
    "Delete {link}" : "Fjern {link}",
    "Menu" : "Meny",
    "Read only" : "Kun les",
    "Read & Write" : "Les og skriv",
    "Email notification not sent" : "E-post varsel er ikkje sendt!",
    "Password changed successfully" : "Passord er endra",
    "Social share" : "Deling",
    "%s password changed successfully" : "%spassord er endra",
    "{fileName} link" : "{fileName} lenke",
    "Edit link share: {name}" : "Endre delt lenke: {name}",
    "Create link share: {name}" : "Opprett delt lenke: (name)",
    "Owner: {owner}" : "Eigar: {owner}",
    "Email notification was sent!" : "E-post varsel er sendt!",
    "You are trying to access a private link. Please log in first." : "Ver venleg å logge inn for å få tilgang til privat lenke.",
    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Din instans har mange filer og/enn brukarar. For å sikre god oppgradering ver venleg å bruk kommandolinje oppdatering (occ upgrade).",
    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Automatisk oppgradering er skrudd av i config.php. For å oppgradere ver venleg å bruke kommando linje oppdatering (occ upgrade).",
    "Imprint" : "Impressum"
},
"nplurals=2; plural=(n != 1);");
